
package require critcl
package provide bzcrit 1.0

critcl::ccode {
  #include "bzReadCrit.c"
   #include "blocksort.c"
   #include "bzlib.c"
   #include "compress.c"
   #include "huffman.c"
   #include "crctable.c"
   #include "randtable.c"
   #include "decompress.c"
}
critcl::cproc bzReadFile {char *fileName} char* {
  return bztclLite_readFileCmd (fileName);
}

