#ifdef USE_TK
#include <tk.h>
#else
#include <tcl.h>
#endif
#include <ctype.h>

#include <errno.h>
#include <string.h>
#include <sys/stat.h>

#include <unistd.h>
#include <stdlib.h>
#ifdef OS_WIN
# include <windows.h>
#endif

#include "memFile.h"
extern memFileData *tclTkInitData[];

/*
** Do an immediate exit.  Do not attempt a clean shutdown.  Just die.
*/
static int hardExitCmd(
  void *NotUsed,             /* Client data for this command */ 
  Tcl_Interp *interp,        /* The interpreter used to report errors */
  int objc,                  /* Number of arguments */
  Tcl_Obj *const* objv       /* Values of all arguments */
){
  exit(0);
}



/*
** This is the main routine.
*/
int main(int argc, char **argv){
  Tcl_Interp *interp;
  interp = memCreateInterp(argc, argv);
  return 0;
}

