#source matchindir.tcl
#load ./memFile.so
#set auto_path /mem
puts "auto_path: $auto_path"
puts "CHILDREN: [namespace children ::tcl::]"
puts [::tcl::tm::list]
puts "CHILDREN2: [namespace children ::tcl::]"
#set ::tcl::tm::paths [glob /mem/tcl8/*]
puts "tm_path: $::tcl::tm::paths"
puts "tm_procs: [info procs ::tcl::tm::*]"
# puts "TRY: [::tcl::tm::UnknownHandler {} msgcat {}]"
puts "REQ: [package require msgcat]"
puts "msgcatpref: [::msgcat::mcpreferences]"
puts "NOW is: [clock format [clock seconds]]" 

puts "START PkgReq"
puts "Load DES: [package require des]"
puts "DONE PkgReq"

set d [DES::des -mode encode -key foo -- "this is a test"]
puts [DES::des -mode decode -key foo -- $d]

