puts "MEMMAIN: start memMain.tcl : AC: $argc AV0: $argv0 AV: $argv"
set argv0 [lindex $argv 0]
set argv [lrange $argv 1 end]
set argc [llength $argv]

puts "MEMMAIN: post memMain.tcl : AC: $argc AV0: $argv0 AV: $argv"

if {[string first .tcl $argv0] >= 0} {
  puts "MEMMAIN: Sourcing: $argv0"
  source $argv0
  puts "MEMMAIN: EXIT NEXT"
} else {
  puts "MEMMAIN: GOING INTERACTIVE"
  set mem_Tcl_Complete 1
  puts "MEMMAIN: DONE SET 1"
  set tcl_interactive 1
  puts "MEMMAIN DONE SET 2"
#  vwait mem_Tcl_Complete
  puts "MEMMAIN DONE VWAIT"
}
